/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.adl;

import java.util.Map;

import org.objectweb.fractal.adl.ADLException;
import org.objectweb.fractal.api.Component;

/**
 * Reconfiguration interface. Allows to add components to a composite following
 * an ADL definition.
 */
public interface Reconfiguration
{

  /**
   * Adds sub component to the given composite component. The given ADL
   * definition is a description of the given composite, where sub components
   * set as <i>legacy </i> (tag
   * <code>&lt;legacy contingency="mandatory"/&gt;</code>) are existing
   * components and others are added components. Legacy component are retreived
   * as direct or indirect sub component of the given composite. They can also
   * be retreive in the <code>context</code> map with a key of the form :
   * <code>"legacy:./&lt;path-to-the-legacy-component&gt;"</code>
   * 
   * @param composite the componite component.
   * @param reconfADL the reconfiguration ADL.
   * @param context a context.
   * @throws ADLException if an error occurs.
   */
  void addComponents(Component composite, String reconfADL, Map context)
      throws ADLException;
}